@@ -6,7 +6,7 @@ for (const shell of [Bash, Zsh, Fish, PowerShell]) {
   describe(shell, () => {
     test(`uninstalls a version`, async () => {
       await script(shell)
-        .then(shell.call("fnm", ["install", "12.0.0"]))
+        .then(shell.call("fnm", ["i", "12.0.0"]))
         .then(shell.call("fnm", ["alias", "12.0.0", "hello"]))
         .then(
           shell.scriptOutputContains(
@@ -14,7 +14,7 @@ for (const shell of [Bash, Zsh, Fish, PowerShell]) {
             "hello"
           )
         )
-        .then(shell.call("fnm", ["uninstall", "hello"]))
+        .then(shell.call("fnm", ["uni", "hello"]))
         .then(
           shell.hasCommandOutput(
             shell.call("fnm", ["ls"]),
