@@ -14,7 +14,7 @@ pub enum SubCommand {
     LsLocal(commands::ls_local::LsLocal),
 
     /// Install a new Node.js version
-    #[clap(name = "install", bin_name = "install")]
+    #[clap(name = "install", bin_name = "install", visible_aliases = &["i"])]
     Install(commands::install::Install),
 
     /// Change Node.js version
@@ -66,8 +66,8 @@ pub enum SubCommand {
     /// Uninstall a Node.js version
     ///
     /// > Warning: when providing an alias, it will remove the Node version the alias
-    /// is pointing to, along with the other aliases that point to the same version.
-    #[clap(name = "uninstall", bin_name = "uninstall")]
+    /// > is pointing to, along with the other aliases that point to the same version.
+    #[clap(name = "uninstall", bin_name = "uninstall", visible_aliases = &["uni"])]
     Uninstall(commands::uninstall::Uninstall),
 }
 
