@@ -2,15 +2,15 @@ use super::alias::Alias;
 use super::command::Command;
 use crate::config::FnmConfig;
 use crate::user_version::UserVersion;
-use structopt::StructOpt;
 
-#[derive(StructOpt, Debug)]
+#[derive(clap::Parser, Debug)]
 pub struct Default {
     version: UserVersion,
 }
 
 impl Command for Default {
     type Error = super::alias::Error;
+
     fn apply(self, config: &FnmConfig) -> Result<(), Self::Error> {
         Alias {
             name: "default".into(),
@@ -18,7 +18,8 @@ impl Command for Default {
         }
         .apply(config)
     }
+
     fn handle_error(err: Self::Error, config: &FnmConfig) {
-        Alias::handle_error(err, config)
+        Alias::handle_error(err, config);
     }
 }
