@@ -22,8 +22,8 @@ impl From<&str> for LtsType {
 impl Display for LtsType {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
         match self {
-            Self::Latest => write!(f, "latest"),
-            Self::CodeName(s) => write!(f, "{s}"),
+            Self::Latest => f.write_str("latest"),
+            Self::CodeName(s) => f.write_str(s),
         }
     }
 }
