@@ -1,4 +1,4 @@
-use crate::version::Version;
+use crate::{pretty_serde::DecodeError, version::Version};
 use serde::Deserialize;
 use url::Url;
 
@@ -62,8 +62,18 @@ pub struct IndexedNodeVersion {
     pub version: Version,
     #[serde(with = "lts_status")]
     pub lts: Option<String>,
-    pub date: chrono::NaiveDate,
-    pub files: Vec<String>,
+    // pub date: chrono::NaiveDate,
+    // pub files: Vec<String>,
+}
+
+#[derive(Debug, thiserror::Error, miette::Diagnostic)]
+pub enum Error {
+    #[error("can't get remote versions file: {0}")]
+    #[diagnostic(transparent)]
+    Http(#[from] crate::http::Error),
+    #[error("can't decode remote versions file: {0}")]
+    #[diagnostic(transparent)]
+    Decode(#[from] DecodeError),
 }
 
 /// Prints
@@ -71,10 +81,16 @@ pub struct IndexedNodeVersion {
 /// ```rust
 /// use crate::remote_node_index::list;
 /// ```
-pub fn list(base_url: &Url) -> Result<Vec<IndexedNodeVersion>, crate::http::Error> {
+pub fn list(base_url: &Url) -> Result<Vec<IndexedNodeVersion>, Error> {
+    let base_url = base_url.as_str().trim_end_matches('/');
     let index_json_url = format!("{base_url}/index.json");
-    let resp = crate::http::get(&index_json_url)?;
-    let mut value: Vec<IndexedNodeVersion> = resp.json()?;
+    let resp = crate::http::get(&index_json_url)
+        .map_err(crate::http::Error::from)?
+        .error_for_status()
+        .map_err(crate::http::Error::from)?;
+    let text = resp.text().map_err(crate::http::Error::from)?;
+    let mut value: Vec<IndexedNodeVersion> =
+        serde_json::from_str(&text[..]).map_err(|cause| DecodeError::from_serde(text, cause))?;
     value.sort_by(|a, b| a.version.cmp(&b.version));
     Ok(value)
 }
