@@ -13,7 +13,7 @@ pub use bash::Bash;
 pub use fish::Fish;
 pub use infer::infer_shell;
 pub use powershell::PowerShell;
-pub use shell::{Shell, AVAILABLE_SHELLS};
+pub use shell::{Shell, Shells};
 pub use windows_cmd::WindowsCmd;
 pub use windows_compat::maybe_fix_windows_path;
 pub use zsh::Zsh;
